@@ -26,6 +26,7 @@ use English qw( -no_match_vars ) ;
 
 use Readonly ;
 Readonly my $EMPTY_STRING => q{} ;
+Readonly my $SCALAR_TYPE=> q{} ;
 
 Readonly my $RANGE_DEFINITON_FIELDS => 4 ;
 
@@ -37,12 +38,6 @@ use Carp qw(carp croak confess) ;
 
 Data::HexDump::Range::Gather - Handles gathering of binary data  for Data::HexDump::Range
 
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-=head1 DOCUMENTATION
-
 =head1 SUBROUTINES/METHODS
 
 Subroutines prefixed with B<[P]> are not part of the public API and shall not be used directly.
@@ -97,8 +92,13 @@ my $location = "$self->{FILE}:$self->{LINE}" ;
 my $used_data = $offset || 0 ;
 $self->{INTERACTION}{DIE}("Error: Invalid negative offset at '$location'.\n") if($used_data < 0) ;
 
-$size = defined $size ? min($size, length($data) - $used_data) : length($data) - $used_data ;
-my $maximum_size = $size ;
+my $data_size = length($data) ;
+
+$self->{INTERACTION}{DIE}("Error: offset greater than data size at '$location'.\n") if($data_size <= $used_data) ;
+
+$size = defined $size ? min($size, $data_size - $used_data) : $data_size - $used_data ;
+$self->{INTERACTION}{DIE}("Error: Invalid negative size at '$location'.\n") if($size < 0) ;
+$self->{INTERACTION}{DIE}("Error: Invalid size '0' at '$location'.\n") if($size == 0) ;
 
 my $skip_remaining_ranges = 0 ;
 my $last_data = '' ;
@@ -165,7 +165,7 @@ while(my $range  = $range_provider->($self, $data, $used_data))
 	my ($is_header, $is_comment, $is_bitfield, $is_skip, $unpack_format) ;
 
 	# handle maximum_size
-	if($EMPTY_STRING eq ref($range_size))
+	if($SCALAR_TYPE eq ref($range_size))
 		{
 		($is_header, $is_comment, $is_bitfield, $is_skip, $range_size, undef) = $self->unpack_range_size($range_name, $range_size, $used_data) ;
 		}
@@ -179,17 +179,23 @@ while(my $range  = $range_provider->($self, $data, $used_data))
 		}
 
 	my $truncated_size ;
-	if($maximum_size - $used_data < $range_size)
+	if($data_size - $used_data < $range_size)
 		{
-		$range_size = $truncated_size = max($maximum_size - $used_data, 0) ;
+		$range_size = $truncated_size = max($data_size - $used_data, 0) ;
 		$skip_remaining_ranges++ ;
 		}
+	elsif($size < $range_size)
+		{
+		$range_size = $truncated_size = $size ;
+		$skip_remaining_ranges++ ;
+		}
+		
 	# get the unpack format with the justified size
 	# note that we keep $is_comment and $is_bitfield from first run
 	# as the those are extracted from the size field and we have modified it
 	(undef,undef, undef, undef, $range_size, $unpack_format) = $self->unpack_range_size($range_name, $range_size, $used_data) ;
 	
-	if($maximum_size == $used_data)
+	if($data_size == $used_data)
 		{
 		if($is_header || $is_comment || $is_bitfield)
 			{
@@ -198,9 +204,14 @@ while(my $range  = $range_provider->($self, $data, $used_data))
 		else
 			{
 			my $next_range  = $range_provider->($self, $data, $used_data) ;
-			$self->{INTERACTION}{WARN}("Warning: More ranges to display but no more data.\n") if defined $next_range ;
 			
-			last ;
+			if(defined $next_range)
+				{
+				my ($next_range_name, $next_range_size_definition) = @{$next_range} ;
+				$self->{INTERACTION}{WARN}("Warning: More ranges to display but no more data.Next range name '$next_range_name'\n")  ;
+				}
+			
+			$skip_remaining_ranges++ ;
 			}
 		}
 		
@@ -357,10 +368,7 @@ else
 	$range_provider = 
 		sub
 		{
-		while(@{$ranges})
-			{
-			return shift @{$ranges} ;
-			}
+		return shift @{$ranges} ;
 		}
 	}
 
@@ -535,10 +543,22 @@ eval
 
 if($EVAL_ERROR)
 	{
-	chomp $EVAL_ERROR ;
+	my ($error_message, $range_index) = @{ $EVAL_ERROR } ;
+	chomp $error_message ;
 
 	use Data::TreeDumper ;
-	$self->{INTERACTION}{DIE}->(DumpTree \@ranges, $EVAL_ERROR) ;
+	use List::MoreUtils qw(pairwise) ;
+	
+	my @keys = ('name', 'size', 'color (optional)',  'user comment (optional)') ;
+
+	$self->{INTERACTION}{DIE}->
+		(
+		DumpTree 
+			{ pairwise { ( $a, $b) } @keys, @{$ranges[$range_index]} },
+			"Range index $range_index: $error_message",
+			QUOTE_VALUES => 1,
+		        TYPE_FILTERS => {'HASH' => sub {'HASH', undef, @keys }, }
+		) ;
 	}
 
 @ranges = () ;
@@ -584,10 +604,22 @@ eval
 
 if($EVAL_ERROR)
         {
-	chomp $EVAL_ERROR ;
+	my ($error_message, $range_index) = @{ $EVAL_ERROR } ;
+	chomp $error_message ;
 
         use Data::TreeDumper ;
-        $self->{INTERACTION}{DIE}->(DumpTree $range_description, $EVAL_ERROR) ;
+	use List::MoreUtils qw(pairwise) ;
+	
+	my @keys = ('name', 'size', 'color (optional)',  'user comment (optional)') ;
+
+	$self->{INTERACTION}{DIE}->
+		(
+		DumpTree 
+			{ pairwise { ( $a, $b) } @keys, @{$range_description->[$range_index]} },
+			"Range index $range_index: $error_message",
+			QUOTE_VALUES => 1,
+		        TYPE_FILTERS => {'HASH' => sub {'HASH', undef, @keys }, }
+		) ;
         }
 
 my @ranges ;
@@ -624,38 +656,39 @@ I<Exceptions> - Croaks with an error messge if the input data is invalid
 =cut
 
 my $self = shift ;
-my $location = "$self->{FILE}:$self->{LINE}" ;
+#my $location = "$self->{FILE}:$self->{LINE}" ;
+
+my $index = -1 ;
 
 map 
 	{
 	my  $description = $_ ;
-	
+	$index++ ;
+
 	if(ref($description) eq 'ARRAY')
 		{
 		if(@{$description} == 0)
 			{
-			$self->{INTERACTION}{DIE}->("Error: no elements in range description at '$location'.") ;
+			$self->{INTERACTION}{DIE}->(["Error: no elements in range description.", $index]) ;
 			}
 			
 		if(all {'' eq ref($_) || 'CODE' eq ref($_) } @{$description} )
 			{
 			if(@{$description} == 0)
 				{
-				$self->{INTERACTION}{DIE}->
-					(
-					"Error: no elements in range description at '$location'." 
-					) ;
+				$self->{INTERACTION}{DIE}->(["Error: no elements in range description.", $index]) ;
 				}
 			elsif(@{$description} == 1)
 				{
 				if('' eq ref($description->[0]))
 					{
 					$self->{INTERACTION}{DIE}->
-						(
+						([
 						"Error: too few elements in range description [" 
 						. join(', ', map {defined $_ ? $_ : 'undef'} @{$description})  
-						. "] at '$location'." 
-						) ;
+						. "]." ,
+						$index
+						]) ;
 					}
 				else
 					{
@@ -681,11 +714,12 @@ map
 			elsif(@{$description} > $RANGE_DEFINITON_FIELDS)
 				{
 				$self->{INTERACTION}{DIE}->
-					(
+					([
 					"Error: too many elements in range description [" 
 					. join(', ', map {defined $_ ? $_ : 'undef'} @{$description}) 
-					. "] at '$location'." 
-					) ;
+					. "].",
+					$index
+					]) ;
 				}
 				
 			@{$description} ;
